cofe.space package
==================

Submodules
----------

cofe.space.basis module
-----------------------

.. automodule:: cofe.space.basis
   :members:
   :undoc-members:
   :show-inheritance:

cofe.space.cluster module
-------------------------

.. automodule:: cofe.space.cluster
   :members:
   :undoc-members:
   :show-inheritance:

cofe.space.clusterspace module
------------------------------

.. automodule:: cofe.space.clusterspace
   :members:
   :undoc-members:
   :show-inheritance:

cofe.space.constants module
---------------------------

.. automodule:: cofe.space.constants
   :members:
   :undoc-members:
   :show-inheritance:

cofe.space.domain module
------------------------

.. automodule:: cofe.space.domain
   :members:
   :undoc-members:
   :show-inheritance:

cofe.space.orbit module
-----------------------

.. automodule:: cofe.space.orbit
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cofe.space
   :members:
   :undoc-members:
   :show-inheritance:
